--------------------------------------------------------------------
create or replace package cw_asthma is
--------------------------------------------------------------------
procedure put(r in out cw_asthma_table%rowtype);
function get(iid in number) return cw_asthma_table%rowtype;
function next(n in out cw_asthma_table%rowtype) return boolean;
function new return cw_asthma_table%rowtype;
procedure rm(iid in number);
function rowcount return number;
procedure make(cookie in varchar2, handler in varchar2,
     student_id       number,
     nurse_id         number,
     h_onset          varchar2,
     h_breath         varchar2,
     h_chest          varchar2,
     pefr             varchar2,
     ayear            varchar2,
     rr               varchar2,
     alert            varchar2,
     dyspnea          varchar2,
     muscle           varchar2,
     color            varchar2,
     auscultation      varchar2,
     so2              varchar2);
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_asthma is
--------------------------------------------------------------------
this cw_asthma_table%rowtype;

cursor nrow is
   select * from cw_asthma_table;
--------------------------------------------------------------------
procedure put(r in out cw_asthma_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_asthma_table
   where id = this_id
   for update of student_id;

   begin
	if r.id is null then
	   select cw_asthma_seq.nextval into r.id
	   from dual;
	   insert into cw_asthma_table
	   (id,student_id,nurse_id,h_onset,h_breath,h_chest,pefr,ayear,rr,
            alert,dyspnea,muscle,color,auscultation,so2)
	   values
	   (r.id,r.student_id,r.nurse_id,r.h_onset,r.h_breath,r.h_chest,r.pefr,
             r.ayear,r.rr,r.alert,r.dyspnea,r.muscle,r.color,r.auscultation,r.so2);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_asthma_table set
		   student_id	= r.student_id,
		   nurse_id	= r.nurse_id,
		   h_onset	= r.h_onset,
                   h_breath     = r.h_breath,
                   h_chest      = r.h_chest,
                   pefr 	= r.pefr,
                   ayear        = r.ayear,
                   rr           = r.rr,
                   alert	= r.alert,
                   dyspnea      = r.dyspnea,
                   muscle       = r.muscle,
                   color        = r.color,
                   auscultation  = r.auscultation,
                   so2          = r.so2
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_asthma.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_asthma_table%rowtype is
cursor c (this_id number) is
   select * from cw_asthma_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_asthma.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_asthma_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_asthma.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_asthma_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_asthma_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_asthma.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_asthma_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_asthma.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------
procedure make(cookie in varchar2, handler in varchar2,
     student_id       number,
     nurse_id         number,
     h_onset          varchar2,
     h_breath         varchar2,
     h_chest          varchar2,
     pefr             varchar2,
     ayear            varchar2,
     rr               varchar2,
     alert            varchar2,
     dyspnea          varchar2,
     muscle           varchar2,
     color            varchar2,
     auscultation     varchar2,
     so2              varchar2) is

r cw_asthma_table%rowtype;
begin
        r.student_id        := student_id; 
        r.nurse_id          := nurse_id;
        r.h_onset           := h_onset;
        r.h_breath          := h_breath;
        r.h_chest           := h_chest;
        r.pefr              := pefr;
        r.ayear             := ayear;
        r.rr                := rr;
 	r.alert   	    := alert;
 	r.dyspnea 	    := dyspnea;
 	r.muscle	    := muscle;
	r.color		    := color;
	r.auscultation	    := auscultation;
	r.so2		    := so2;

        if handler = 'cw_asthma_mgr.create_action' then
	cw_asthma_mgr.create_action(cookie,r);
	elsif handler = 'cw_asthma_mgr.modify_action' then
         cw_asthma_mgr.modify_action(cookie,r);
	else
		null;
	end if;
end;
----------------------------------------------------------------------
end;
/
show errors
