--------------------------------------------------------------------
create or replace package cw_careinfo is
--------------------------------------------------------------------
procedure put(r in out cw_careinfo_table%rowtype);
function get(iid in number) return cw_careinfo_table%rowtype;
function next(n in out cw_careinfo_table%rowtype) return boolean;
function new return cw_careinfo_table%rowtype;
procedure rm(iid in number);
function rowcount return number;
procedure make(cookie in varchar2, handler in varchar2,
	health_provider in varchar2,
	health_insur in varchar2,
	medicaid in varchar2,
	treat_permission in varchar2,
	emergency_contact in varchar2,
	not_releaseto in varchar2,
	emergency_protocol in varchar2,
	allergy_type in varchar2,
	allergy_reaction in varchar2);
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_careinfo is
--------------------------------------------------------------------
this cw_careinfo_table%rowtype;

cursor nrow is
   select * from cw_careinfo_table;
--------------------------------------------------------------------
procedure put(r in out cw_careinfo_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_careinfo_table
   where id = this_id
   for update of student_id;

   begin
	if r.id is null then
	   select cw_careinfo_seq.nextval into r.id
	   from dual;
	   insert into cw_careinfo_table
	   (id,student_id,nurse_id,health_provider,health_insur,
	    medicaid,treat_permission,emergency_contact,not_releaseto,
	    emergency_protocol,allergy_type,allergy_reaction )
	   values
	   (r.id,r.student_id,r.nurse_id,r.health_provider,r.health_insur,
	    r.medicaid,r.treat_permission,r.emergency_contact,r.not_releaseto,
	    r.emergency_protocol,r.allergy_type,r.allergy_reaction );
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_careinfo_table set
		   student_id		= r.student_id,
		   nurse_id		= r.nurse_id,
		   health_provider	= r.health_provider,
		   health_insur		= r.health_insur,
		   medicaid		= r.medicaid,
		   treat_permission	= r.treat_permission,
		   emergency_contact	= r.emergency_contact,
		   not_releaseto	= r.not_releaseto,
		   emergency_protocol	= r.emergency_protocol,
		   allergy_type		= r.allergy_type,
		   allergy_reaction	= r.allergy_reaction
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
	commit;
   exception	   
	when others then
	   cw_error.panic('cw_careinfo.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_careinfo_table%rowtype is
cursor c (this_id number) is
   select * from cw_careinfo_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_careinfo.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_careinfo_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_careinfo.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_careinfo_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_careinfo_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_careinfo.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_careinfo_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_careinfo.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------
procedure make(cookie in varchar2, handler in varchar2,
        health_provider in varchar2,
        health_insur in varchar2,
        medicaid in varchar2,
        treat_permission in varchar2,
        emergency_contact in varchar2,
        not_releaseto in varchar2,
	emergency_protocol in varchar2,
        allergy_type in varchar2,
        allergy_reaction in varchar2) is
r cw_careinfo_table%rowtype;
begin
	r.health_provider	:= health_provider;
	r.health_insur		:= health_insur;
	r.medicaid		:= medicaid;
	r.treat_permission	:= treat_permission;
	r.emergency_contact	:= emergency_contact;
	r.not_releaseto		:= not_releaseto;
	r.emergency_protocol	:= emergency_protocol;
	r.allergy_type		:= allergy_type;
	r.allergy_reaction	:= allergy_reaction;

	if handler = 'cw_careinfo_mgr.create_action' then
		cw_careinfo_mgr.create_action(cookie,r);
	elsif handler = 'cw_careinfo_mgr.modify_action' then
		cw_careinfo_mgr.modify_action(cookie,r);
	else
		null;
	end if;
end;
----------------------------------------------------------------------

end;
/
show errors
