--------------------------------------------------------------------
create or replace package cw_customer is
--------------------------------------------------------------------
procedure put(r in out cw_customer_table%rowtype);
function get(iid in number) return cw_customer_table%rowtype;
function get(iname in varchar2) return cw_customer_table%rowtype;
function next(n in out cw_customer_table%rowtype) return boolean;
procedure new(n in out cw_customer_table%rowtype);
function rowcount return number;
procedure rm(iid in number);
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_customer is
--------------------------------------------------------------------
this cw_customer_table%rowtype;

cursor nrow is
   select * from cw_customer_table;
--------------------------------------------------------------------
procedure put(r in out cw_customer_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_customer_table
   where id = this_id
   for update of username;

   begin
	if r.id is null then
	   select cw_customer_seq.nextval into r.id
	   from dual;
	   insert into cw_customer_table
	   (id,username,password,person_id,role,conn_count,
	    first_tx_id,last_tx_id)
	   values
	   (r.id,r.username,r.password,r.person_id,r.role,r.conn_count,
	    r.first_tx_id,r.last_tx_id);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_customer_table set
		   username	= r.username,
		   password	= r.password,
		   person_id	= r.person_id,
		   role		= r.role,
		   conn_count	= r.conn_count,
		   first_tx_id	= r.first_tx_id,
		   last_tx_id	= r.last_tx_id
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_customer.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_customer_table%rowtype is
cursor c (this_id number) is
   select * from cw_customer_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_customer.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function get(iname in varchar2) return cw_customer_table%rowtype is
cursor c (this_name varchar2) is
   select * from cw_customer_table
   where username = this_name;
begin
   open c(iname);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_customer.get username='||iname,sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_customer_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_customer.next',sqlerrm);

end;
---------------------------------------------------------------------
procedure new(n in out cw_customer_table%rowtype) is
begin
   n.id := null;
   put(n);
exception
   when others then
	cw_error.panic('cw_customer.new',sqlerrm);
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
begin
   delete from cw_customer_table
   where id = iid;
exception
   when others then
	cw_error.panic('cw_customer.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_customer_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_customer.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------

end;
/
show errors
