--------------------------------------------------------------------
create or replace package cw_develscr is
--------------------------------------------------------------------
procedure put(r in out cw_develscr_table%rowtype);
function get(iid in number) return cw_develscr_table%rowtype;
function next(n in out cw_develscr_table%rowtype) return boolean;
function new return cw_develscr_table%rowtype;
procedure rm(iid in number);
procedure make(cookie in varchar2, handler in varchar2,
    student_id         in  number,
    idaym              in varchar2,
    idayd              in varchar2,
    idayy              in varchar2,
    age                in   number,
    concern            in varchar2,
    fd_changes         in varchar2,
    fd_moves           in varchar2,
    fd_stresses        in varchar2,
    fd_control         in varchar2,
    fd_communication   in varchar2,
    fd_strained        in varchar2,
    ag_home            in varchar2,
    ag_education       in varchar2,
    ag_abuse           in varchar2,
    ag_drugs           in varchar2,
    ag_safety          in varchar2,
    ag_friends         in varchar2,
    ag_image           in varchar2,
    ag_recreation      in varchar2,
    ag_sexuality       in varchar2,
    ag_threats         in varchar2,
    moccupation        in varchar2,
    foccupation        in varchar2,
    grade              in varchar2,
    job                in varchar2,
    water              in varchar2,
    pets               in varchar2,
    recent             in varchar2,
    who_athome         in varchar2,
    breakfast          in varchar2,
    lunch              in varchar2,
    dinner             in varchar2,
    snacks             in varchar2,
    comments           in varchar2,
    nurse_sig          in varchar2);
function rowcount return number;
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_develscr is
--------------------------------------------------------------------
this cw_develscr_table%rowtype;

cursor nrow is
   select * from cw_develscr_table;
--------------------------------------------------------------------
procedure put(r in out cw_develscr_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_develscr_table
   where id = this_id
   for update of nurse_sig;

   begin
	if r.id is null then
	   select cw_develscr_seq.nextval into r.id
	   from dual;
	   insert into cw_develscr_table
	   (id,student_id,tdate,age,concern,fd_changes,fd_moves,fd_stresses,
            fd_control,fd_communication,fd_strained,ag_home,ag_education,
	    ag_abuse,ag_drugs,ag_safety,ag_friends,ag_image,ag_recreation,
            ag_sexuality,ag_threats,moccupation,foccupation,grade,job,water,
            pets,recent,who_athome,breakfast,lunch,dinner,snacks,
            comments,nurse_sig)
	   values
	   (r.id,r.student_id,r.tdate,r.age,r.concern,r.fd_changes,r.fd_moves,
	    r.fd_stresses,r.fd_control,r.fd_communication,r.fd_strained,
            r.ag_home,r.ag_education,r.ag_abuse,r.ag_drugs,r.ag_safety,
	    r.ag_friends,r.ag_image,r.ag_recreation,r.ag_sexuality,r.ag_threats,
            r.moccupation,r.foccupation,r.grade,r.job,r.water,r.pets,r.recent,
            r.who_athome,r.breakfast,r.lunch,r.dinner,r.snacks,
            r.comments,r.nurse_sig);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_develscr_table set
		   student_id		= r.student_id,
		   tdate		= r.tdate,
		   age	      	  	= r.age,
		   concern		= r.concern,
		   fd_changes		= r.fd_changes,
		   fd_moves		= r.fd_moves,
		   fd_stresses		= r.fd_stresses,
		   fd_control  		= r.fd_control,
		   fd_communication	= r.fd_communication,
		   fd_strained		= r.fd_strained,
		   ag_home		= r.ag_home,
		   ag_education		= r.ag_education,
		   ag_abuse 	        = r.ag_abuse ,
		   ag_drugs 	        = r.ag_drugs,
		   ag_safety	        = r.ag_safety,
		   ag_friends	        = r.ag_friends,
		   ag_image     	= r.ag_image,
		   ag_recreation        = r.ag_recreation,
		   ag_sexuality		= r.ag_sexuality,
		   ag_threats		= r.ag_threats,
		   moccupation		= r.moccupation,
                   foccupation 		= r.foccupation ,
       	           grade		= r.grade,
                   job			= r.job,
                   water	 	= r.water,
                   pets			= r.pets,
                   recent		= r.recent,
	           who_athome		= r.who_athome,
 	           breakfast		= r.breakfast,
 	           lunch		= r.lunch,
                   dinner		= r.dinner,
                   snacks		= r.snacks,
                   comments		= r.comments,
                   nurse_sig		= r.nurse_sig
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_develscr.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_develscr_table%rowtype is
cursor c (this_id number) is
   select * from cw_develscr_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_develscr.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_develscr_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_develscr.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_develscr_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_develscr_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_develscr.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
procedure make(cookie in varchar2, handler in varchar2,
	 student_id         in  number, 
         idaym              in   varchar2,
         idayd              in   varchar2,
         idayy              in   varchar2,
    	 age                in   number, 
   	 concern            in varchar2,
  	 fd_changes         in varchar2,
   	 fd_moves           in varchar2,
   	 fd_stresses        in varchar2,
   	 fd_control         in varchar2,
   	 fd_communication   in varchar2,
   	 fd_strained        in varchar2,
   	 ag_home            in varchar2,
   	 ag_education       in varchar2,
   	 ag_abuse           in varchar2,
   	 ag_drugs           in varchar2,
   	 ag_safety          in varchar2,
    	 ag_friends         in varchar2,
    	 ag_image           in varchar2,
   	 ag_recreation      in varchar2,
   	 ag_sexuality       in varchar2,
   	 ag_threats         in varchar2,
	 moccupation        in varchar2,
   	 foccupation        in varchar2,
   	 grade              in varchar2,
   	 job                in varchar2,
   	 water              in varchar2,
   	 pets               in varchar2,
   	 recent             in varchar2,
    	 who_athome         in varchar2,
   	 breakfast          in varchar2,
    	 lunch              in varchar2,
   	 dinner             in varchar2,
   	 snacks             in varchar2,
         comments           in varchar2,
   	 nurse_sig          in varchar2 ) is
r cw_develscr_table%rowtype;
ldate date;
begin   
           ldate := to_date(idaym||idayd||idayy, 'MONDDYYYY');
                   r.student_id		:= student_id;
		   r.tdate	        := ldate;
		   r.age 	        := age;
		   r.concern		:= concern;
		   r.fd_changes		:= fd_changes;
		   r.fd_moves		:= fd_moves;
		   r.fd_stresses	:= fd_stresses;
		   r.fd_control         := fd_control;
		   r.fd_communication	:= fd_communication;
		   r.fd_strained	:= fd_strained;
		   r.ag_home		:= ag_home;
		   r.ag_education	:= ag_education;
		   r.ag_abuse 	        := ag_abuse ;
		   r.ag_drugs 	        := ag_drugs;
		   r.ag_safety	        := ag_safety;
		   r.ag_friends	        := ag_friends;
		   r.ag_image        	:= ag_image;
		   r.ag_recreation      := ag_recreation;
		   r.ag_sexuality	:= ag_sexuality;
		   r.ag_threats		:= ag_threats;
		   r.moccupation	:= moccupation;
                   r.foccupation	:= foccupation ;
       		   r.grade	    	:= grade;
         	   r.job	      	:= job;
         	   r.water	    	:= water;
                   r.pets	    	:= pets;
                   r.recent	     	:= recent;
	      	   r.who_athome		:= who_athome;
 	     	   r.breakfast		:= breakfast;
 	           r.lunch	        := lunch;
           	   r.dinner		:= dinner;
           	   r.snacks	        := snacks;
                   r.comments	       	:= comments;
                   r.nurse_sig          := nurse_sig;
	 
	if handler = 'cw_develscr_mgr.create_action' then
	cw_develscr_mgr.create_action(cookie,r);
	elsif handler = 'cw_develscr_mgr.modify_action' then
         cw_develscr_mgr.modify_action(cookie,r);
	else
		null;
	end if;
end;
----------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_develscr_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_develscr.rowcount',sqlerrm);
end;
----------------------------------------------------------------------------------
end;
/
show errors
