--------------------------------------------------------------------
create or replace package cw_doctor is
--------------------------------------------------------------------
procedure put(r in out cw_doctor_table%rowtype);
function get(iid in number) return cw_doctor_table%rowtype;
function next(n in out cw_doctor_table%rowtype) return boolean;
function new return cw_doctor_table%rowtype;
procedure rm(iid in number);
function rowcount return number; 
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_doctor is
--------------------------------------------------------------------
this cw_doctor_table%rowtype;

cursor nrow is
   select * from cw_doctor_table;
--------------------------------------------------------------------
procedure put(r in out cw_doctor_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_doctor_table
   where id = this_id
   for update of person_id;

   begin
	if r.id is null then
	   select cw_doctor_seq.nextval into r.id
	   from dual;
	   insert into cw_doctor_table
	   (id,person_id,cust_id)
	   values
	   (r.id,r.person_id,r.cust_id);	   
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_doctor_table set
		   person_id	= r.person_id,
		   cust_id	= r.cust_id
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_doctor.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_doctor_table%rowtype is
cursor c (this_id number) is
   select * from cw_doctor_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_doctor.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_doctor_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_doctor.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_doctor_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_doctor_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_doctor.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_doctor_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_doctor.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------

end;
/
show errors
