drop package cw_immun;

----------------------------------------------------  
create or replace package cw_immun is  
----------------------------------------------------  
procedure rm (iid in number);
function get(iid in number) return cw_immun_table%rowtype;
procedure put(iorow in out cw_immun_table%rowtype);
function new(iorow in out cw_immun_table%rowtype) return cw_immun_table.id%type;
function next(ionrow in out cw_immun_table%rowtype) return boolean;
-- procedure search_action(column_num in varchar2);  
procedure insert_action(cookie in varchar2, iname in varchar2, igiven_num in number,
                        idaym in varchar2, idayd in varchar2, idayy in varchar2);
procedure update_action(cookie in varchar2, iname in varchar2, igiven_num in number,
                        idaym in varchar2, idayd in varchar2, idayy in varchar2);
procedure delete_action(cookie in varchar2, iid in varchar2); 
end;  
/
show errors;
-- /

---------------------------------------------------------  
create or replace package body cw_immun is  
---------------------------------------------------------  
  me varchar2(64);
  this cw_immun_table%type;
  lstu cw_student_table%type;
  lnur cw_nurse_table%type;
--  id_null exception;
  cursor nrow is
     select * from cw_immun_table order by day;
--
---------------------------------------------------------  
procedure rm (iid in number) is
---------------------------------------------------------  
    begin
      delete from cw_immun_table 
        where id = iid;
--      htp.p('rm:iid='||to_char(iid));
      exception
        when others then
	  cw_error.panic('cw_immun.rm iid=' || to_char(iid),sqlerrm);
  end;
--
---------------------------------------------------------  
function get(iid in number) return cw_immun_table%rowtype is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_immun_table the
      where the.id = this_id;
  begin
    open c (iid);
    fetch c into this;
    if c%notfound then
      raise no_data_found;
    end if;
    close c;
    return this;
    exception
      when no_data_found then
        raise;
      when others then
	cw_error.panic('cw_immun.get iid=' || to_char(iid),sqlerrm);
  end;
--
---------------------------------------------------------  
  procedure put(iorow in out cw_immun_table%rowtype) is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_immun_table
      where id = this_id
      for update  of day;
    begin
      if (iorow.id is null) then
	select cw_immun_seq.nextval into iorow.id
	  from dual;
        insert into cw_immun_table
	  values
	  ( iorow.id, iorow.student_id, iorow.nurse_id, iorow.name,
           iorow.given_num, iorow.day
          );
      else
        open c (iorow.id);
	fetch c into this;
	if c%found then
	  update  cw_immun_table set
            id = iorow.id,
            student_id = iorow.student_id,
            nurse_id = iorow.nurse_id,
            name = iorow.name,
            given_num = iorow.given_num,
            day = iorow.day
	  where id = iorow.id;
	else
	  raise no_data_found;
	end if;
        close c;
      end if;
    exception
      when others then
	cw_error.panic('cw_immun.put iorow.id=' ||iorow.id, sqlerrm);
    end;
--
---------------------------------------------------------  
function new(iorow in out cw_immun_table%rowtype) return cw_immun_table.id%type is
---------------------------------------------------------  
begin
  iorow.id := null;
  put(iorow);
  return iorow.id;
  exception
    when others then
      cw_error.panic('cw_immun.new iorow.id=' ||iorow.id, sqlerrm);
end;
--
---------------------------------------------------------  
function next(ionrow in out cw_immun_table%rowtype) return boolean is
---------------------------------------------------------  
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into ionrow;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_immun.next',sqlerrm);

end;

---------------------------------------------------------  
procedure insert_action(cookie in varchar2, iname in varchar2, igiven_num in number,
                        idaym in varchar2, idayd in varchar2, idayy in varchar2) is
---------------------------------------------------------  
  ldate date;
begin
  me := 'cw_immun.insert_action';
  cw_bridge.sync(me, cookie);
--  this := cw_bridge.get_immun;
  lstu := cw_bridge.get_student;
  lnur := cw_bridge.get_nurse;
  ldate := to_date(idaym||idayd||idayy, 'MONDDYYYY');
  this.student_id := lstu.id;
  this.nurse_id := lnur.id;
  this.name := iname;
  this.given_num := igiven_num;
  this.day := ldate;
  this.id := new(this);
  cw_bridge.set_immun(this);
  cw_immun_util.action_echo(cookie, this, 'inserted');
  exception
    when others then
      cw_error.panic(me|| ':', sqlerrm);
end;  

---------------------------------------------------------  
procedure update_action(cookie in varchar2, iname in varchar2, igiven_num in number,
                        idaym in varchar2, idayd in varchar2, idayy in varchar2) is
---------------------------------------------------------  
  ldate date;
begin  
  me := 'cw_immun.update_action';
  cw_bridge.sync(me, cookie);
  this := cw_bridge.get_immun;
--  lstu := cw_bridge.get_student;
--  lnur := cw_bridge.get_nurse;
--  if (this.id = null) then
--    insert_action(cookie, iname, igiven_num, idaym, idayd, idayy); 
--  else 
    ldate := to_date(idaym||idayd||idayy, 'MONDDYYYY');
--    this.student_id := lstu.id;
--    this.nurse_id := lnur.id;
    this.name := iname;
    this.given_num := igiven_num;
    this.day := ldate;
    put(this);
    cw_immun_util.action_echo(cookie, this, 'updated');
--  end if;
  exception
    when others then
      cw_error.panic(me|| ':', sqlerrm); 
end;  

---------------------------------------------------------  
procedure delete_action(cookie in varchar2, iid in varchar2) is
---------------------------------------------------------  
  lid varchar2(8);
begin  
  lid := iid;
  me := 'cw_immun.delete_action';
  cw_bridge.sync(me, cookie);
--  this := cw_bridge.get_immun;
--  if (this.id = null) then
--    raise id_null;
--  end if;
--  if (iid = null) then
--    raise id_null;
--  end if;
  cw_immun_util.action_echo(cookie, this, 'deleted');
  cw_bridge.unset_immun;  
--  htp.p('delete_action:iid='||iid);
  rm(to_number(lid));
exception
--    when id_null then
--      cw_error.msg(me|| ': iid is null'); 
    when others then
      cw_error.panic(me|| ':', sqlerrm); 
end;  

---------------------------------------------------------  
-- begin
--	this.id := 0;
-- end;
---------------------------------------------------------  

---------------------------------------------------------  
end;  
---------------------------------------------------------  

/
show errors;
-- /

