drop package cw_immunization;

----------------------------------------------------  
create or replace package cw_immunization is  
----------------------------------------------------  
procedure rm (iid in number);
function get(iid in number) return cw_immunization_table%rowtype;
procedure put(iorow in out cw_immunization_table%rowtype);
-- procedure search_action(column_num in varchar2);  
procedure insert_action(cookie in varchar2, igrade in number, iage in number, 
  iimmunization in varchar2,  ireason in varchar2, idosage in varchar2, 
  iimmunization_time in date, idoctor_order in varchar2, iparent_permission in varchar2, 
  isignature in varchar2, idate in date, idoctor_initial in varchar2, ititle in varchar2);  
procedure update_action(cookie in varchar2, igrade in number, iage in number, 
  iimmunization in varchar2,  ireason in varchar2, idosage in varchar2, 
  iimmunization_time in date, idoctor_order in varchar2, iparent_permission in varchar2, 
  isignature in varchar2, idate in date, idoctor_initial in varchar2, ititle in varchar2); 
procedure delete_action(cookie in varchar2); 
-- procedure search_page(column_num in varchar2);  
procedure insert_page(column_num in varchar2);  
procedure update_page(column_num in varchar2);  
-- procedure delete_page(column_num in varchar2);  

end;  
/
show errors;
-- /

---------------------------------------------------------  
create or replace package body cw_immunization is  
---------------------------------------------------------  
  me varchar2(64);
  this cw_immunization_table%type;
  med_id_null exception;
--
---------------------------------------------------------  
procedure rm (iid in number) is
---------------------------------------------------------  
    begin
      delete from cw_immunization_table 
        where id = to_number(iid);
      exception
        when others then
	  panic('cw_immunization.rm iid=' || to_char(iid),sqlerrm);
  end;
--
---------------------------------------------------------  
function get(iid in number) return cw_immunization_table%rowtype is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_immunization_table the
      where the.id = this_id;
  begin
    open c (iid);
    fetch c into this;
    if c%notfound then
      raise no_data_found;
    end if;
    close c;
    return this;
    exception
      when no_data_found then
        raise;
      when others then
--	panic('cw_immunization.get iid=' || to_char(iid),sqlerrm);
        cw_error.panic(me||':', sqlerrm); 
  end;
--
---------------------------------------------------------  
  procedure put(iorow in out cw_immunization_table%rowtype) is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_immunization_table
      where id = this_id
      for update  of immunization_time;
    begin
      if (iorow.id is null) then
	select cw_immunization_seq.nextval into iorow.id
	  from dual;
        insert into cw_immunization_table
	  values
	  ( iorow.id, iorow.student_id, iorow.grade,
           iorow.age, iorow.immunization, iorow.reason, 
           iorow.dosage, iorow.immunization_time, iorow.doctor_order, 
           iorow.parent_permission, iorow.signature, iorow.doctor_initial, 
           iorow.title, iorow.signature_date  
          );
      else
        open c (iorow.id);
	fetch c into this;
	if c%found then
	  update  cw_immunization_table set
            id = iorow.id,
            student_id = iorow.student_id,
            grade = iorow.grade,
            age = iorow.age,
            immunization = iorow.immunization,
            reason = iorow.reason,
            dosage = iorow.dosage,
            immunization_time = iorow.immunization_time,
            doctor_order = iorow.doctor_order,
            signature_date = iorow.signature_date,
            parent_permission = iorow.parent_permission,
            signature = iorow.signature,
            doctor_initial = iorow.doctor_initial,
            title = iorow.title
	  where id = iorow.id;
	else
	  raise no_data_found;
	end if;
        close c;
      end if;
    exception
      when others then
--	panic('cw_immunization_table.put iorow.id=' || to_char(iorow.id), sqlerrm);
        cw_error.panic(me||':', sqlerrm); 
    end;
--
---------------------------------------------------------  
function new(iorow in out cw_immunization_table%rowtype) return cw_immunization_table.id%type is
---------------------------------------------------------  
begin
  iorow.id := null;
  put(iorow);
  return iorow.id;
  exception
    when others then
      panic('cw_immunization_table.new',sqlerrm);
end;

---------------------------------------------------------  
procedure insert_action(cookie in varchar2, igrade in number, iage in number, 
  iimmunization in varchar2,  ireason in varchar2, idosage in varchar2, 
  iimmunization_time in date, idoctor_order in varchar2, iparent_permission in varchar2, 
  isignature in varchar2, idate in date, idoctor_initial in varchar2, ititle in varchar2) is  
---------------------------------------------------------  
begin  
  cw_util.pageOpen('');
  me := 'cw_immunization.insert_action';
  cw_bridge.restore_state(cookie);
  cw_bridge.med.grade := igrade;
  cw_bridge.med.age := iage;
  cw_bridge.med.immunization := iimmunization;
  cw_bridge.med.reason := ireason;
  cw_bridge.med.dosage := idosage;
  cw_bridge.med.immunization_time := iimmunization_time;
  cw_bridge.med.doctor_order := idoctor_order;
  cw_bridge.med.parent_permission := iparent_permission;
  cw_bridge.med.signature := isignature;
  cw_bridge.med.doctor_initial := idoctor_initial;
  cw_bridge.med.title := ititle;
  cw_bridge.med.signature_date  := idate;
  cw_bridge.med.id := new(cw_bridge.med);
  this := cw_bridge.med;
  htp.p(htf.bold(me)||'has been excuted.');
  cw_util.pageClose;
end;  

---------------------------------------------------------  
procedure update_action(cookie in varchar2, igrade in number, iage in number, 
  iimmunization in varchar2,  ireason in varchar2, idosage in varchar2, 
  iimmunization_time in date, idoctor_order in varchar2, iparent_permission in varchar2, 
  isignature in varchar2, idate in date, idoctor_initial in varchar2, ititle in varchar2) is  
---------------------------------------------------------  
begin  
  cw_util.pageOpen('');
  me := 'cw_immunization.update_action';
  cw_bridge.restore_state(cookie);
  if (cw_bridge.med.id = null) then
    raise med_id_null;
  end if;
  cw_bridge.med.grade := igrade;
  cw_bridge.med.age := iage;
  cw_bridge.med.immunization := iimmunization;
  cw_bridge.med.reason := ireason;
  cw_bridge.med.dosage := idosage;
  cw_bridge.med.immunization_time := iimmunization_time;
  cw_bridge.med.doctor_order := idoctor_order;
  cw_bridge.med.parent_permission := iparent_permission;
  cw_bridge.med.signature := isignature;
  cw_bridge.med.doctor_initial := idoctor_initial;
  cw_bridge.med.title := ititle;
  cw_bridge.med.signature_date  := idate;
  put(cw_bridge.med);
  this := cw_bridge.med;
  htp.p(htf.bold(me)||'has been excuted.');
  cw_util.pageClose;
  exception
    when med_id_null then
      cw_error.msg(me||': cw_bridge.med.id is null'); 
    when others then
--      cw_error.panic(me||': cw_bridge.med.id ='||to_char(cw_bridge.med.id), sqlerrm); 
      cw_error.panic(me||':', sqlerrm); 
end;  

---------------------------------------------------------  
procedure delete_action(cookie in varchar2) is
---------------------------------------------------------  
begin  
  cw_util.pageOpen(''); 
  me := 'cw_immunization.delete_action';
  cw_bridge.restore_state(cookie);
  if (cw_bridge.med.id = null) then
    raise med_id_null;
  end if;
  rm(cw_bridge.med.id);
  htp.p(htf.bold(me)||'has been excuted.');
  cw_util.pageClose; 
  exception
    when med_id_null then
      cw_error.msg(me||': cw_bridge.med.id is null'); 
    when others then
--      cw_error.panic(me||': cw_bridge.med.id ='||to_char(cw_bridge.med.id), sqlerrm); 
      cw_error.panic(me||':', sqlerrm); 
end;  


--------------------------------------------------------- 
-- private procedure 
procedure table_insertrow(name in varchar2, column_num in varchar2) is  
---------------------------------------------------------  
begin  
   htp.tableRowOpen;
   htp.tableData(htf.tableHeader(name));
    for i in 1..TO_NUMBER(column_num) loop
     htp.tableData(htf.formText(name||i, '10', '10', ''));
   end loop;
  htp.tableRowClose;
end;

--------------------------------------------------------- 
-- private procedure 
procedure select_colomns(column_num in number) is  
---------------------------------------------------------  
begin  
   htp.p('most recent');
   htp.formSelectOpen('column_num', '', 1, 'onChange:=""');
   htp.formSelectOption('--', '', 'value:="5"');
   for i in 1..column_num loop
     htp.formSelectOption(i, '', 'value:='||i);
   end loop;
   htp.formSelectClose;
   htp.p('medition(s)');
end;

--------------------------------------------------------- 
-- private procedure 
procedure select_colomns_javascript is  
---------------------------------------------------------  
begin  
   htp.javascriptOpen;
   htp.p('var xcolumn_num:=5;');
   htp.p('var xselectedIndex;');
   htp.p('var visit_num;');
   htp.p('
     function cw_immunization_page() {
       if (visit_num != null) { ');
--         htp.p(' xselectedIndex = parent.frames["cw_right"].document.forms[0].column_num.selectedIndex;
         htp.p(' xselectedIndex = document.forms[0].column_num.selectedIndex;
         xcolumn_num := parent.frames["cw_right"].document.forms[0].column_num.options[xselectedIndex].value;
       } ');
   htp.p('else { xcolumn_num = 5; } ');
       htp.p('alert("It will always show 5 tests, but I can fix this if I can 
             put a invisible column_num variable in your frame."); ');
       htp.p('parent.frames["cw_right"].location = "/owa_careweb/owa/cw_immunization.cw_immunization_page?column_num:="+xcolumn_num;
       visit_num = 1;');
   htp.p('} ');
   htp.javascriptClose;
end;

---------------------------------------------------------  
procedure insert_page(column_num in varchar2) is  
---------------------------------------------------------  
  i number;
begin  
   cw_util.pageOpen(''); 
   select_colomns_javascript;
   htp.javascriptOpen;
   htp.headClose;
   htp.bodyOpen;
   htp.formOpen('dummy', 'POST');
   htp.header(2, 'Medication Record: ');
   htp.p(htf.bold('School: ')||htf.formText('', '20', '20', ''));
   htp.p(htf.bold('Month/Year: ')||htf.formText('', '20', '20', ''));
   htp.br;
   htp.p('<input type:="button" name:="ShowButton", value:="Show" onClick:="cw_immunization_page()">');
   select_colomns(10);
   htp.tableOpen;
   table_insertrow('Grade', column_num );   
   table_insertrow('Age', column_num );   
   table_insertrow('Medication Name', column_num );   
   table_insertrow('Medication Reason', column_num );   
   table_insertrow('Medication Dosage', column_num );   
   table_insertrow('Medication Time', column_num );   
   table_insertrow('Doctor Order', column_num );   
   table_insertrow('Parent Permission', column_num );   
   table_insertrow('Signature', column_num );   
   table_insertrow('Signature Date', column_num );   
   table_insertrow('Initial', column_num );   
   table_insertrow('Title', column_num );   
   table_insertrow('Signature Date', column_num );   
   table_insertrow('Initial', column_num );   
   htp.tableClose;
   htp.formClose;
   cw_util.pageClose;  
end;  

--------------------------------------------------------- 
-- private procedure 
procedure table_updaterow(name in varchar2, column_num in varchar2, value in varchar2) is  
---------------------------------------------------------  
begin  
   htp.tableRowOpen;
   htp.tableData(htf.tableHeader(name));
    for i in 1..TO_NUMBER(column_num) loop
--     htp.tableData(htf.formText('name'||i, '10', '10', ''));
     htp.tableData(htf.formText(name||i, '10', '10', value));
   end loop;
  htp.tableRowClose;
end;

---------------------------------------------------------  
procedure update_page(column_num in varchar2) is  
---------------------------------------------------------  
  i number;
begin  
   cw_util.pageOpen(''); 
   select_colomns_javascript;
   htp.headClose;
   htp.bodyOpen;
   htp.formOpen('dummy', 'POST');
   htp.header(2, 'Medication Record: ');
   htp.p(htf.bold('School: ')||htf.formText('', '20', '20', ''));
   htp.p(htf.bold('Month/Year: ')||htf.formText('', '20', '20', ''));
   htp.br;
   htp.p('<input type:="button" name:="ShowButton", value:="Show" onClick:="cw_immunization_page()">');
   select_colomns(10);
   htp.tableOpen;
   table_updaterow('Grade', column_num, cw_bridge.med.grade);   
   table_updaterow('Age', column_num, cw_bridge.med.age);   
   table_updaterow('Medication Name', column_num, cw_bridge.med.immunization);   
   table_updaterow('Medication Reason', column_num, cw_bridge.med.reason);   
   table_updaterow('Medication Dosage', column_num, cw_bridge.med.dosage);   
   table_updaterow('Medication Time', column_num, cw_bridge.med.immunization_time);   
   table_updaterow('Doctor Order', column_num, cw_bridge.med.doctor_order);   
   table_updaterow('Parent Permission', column_num, cw_bridge.med.parent_permission);   
   table_updaterow('Signature', column_num, cw_bridge.med.signature);   
   table_updaterow('Signature Date', column_num, cw_bridge.med.signature_date);   
   table_updaterow('Title', column_num, cw_bridge.med.title);   
   table_updaterow('Initial', column_num, cw_bridge.med.doctor_initial);   
   htp.tableClose;
   htp.formClose;
   cw_util.pageClose;  
end;  
---------------------------------------------------------  
-- begin
--	this.id := 0;
-- end;
---------------------------------------------------------  

---------------------------------------------------------  
end;  
---------------------------------------------------------  

/
show errors;
-- /
