 drop package cw_medicat;

----------------------------------------------------  
create or replace package cw_medicat is  
----------------------------------------------------  
procedure rm (iid in number);
function get(iid in number) return cw_medicat_table%rowtype;
procedure put(iorow in out cw_medicat_table%rowtype);
function new(iorow in out cw_medicat_table%rowtype) return cw_medicat_table.id%type;
function next(ionrow in out cw_medicat_table%rowtype) return boolean;
-- procedure search_action(column_num in varchar2);  
procedure insert_action(cookie in varchar2, 
  iname in varchar2,  ireason in varchar2, idosage in varchar2, 
  idaym in varchar2, idayd in varchar2, idayy in varchar2, 
  idoctor_order in varchar2, iparent_permission in varchar2, isignature in varchar2, 
  isignature_daym in varchar2, isignature_dayd in varchar2, isignature_dayy in varchar2, 
  idoctor_initial in varchar2, ititle in varchar2);  
procedure update_action(cookie in varchar2, 
  iname in varchar2,  ireason in varchar2, idosage in varchar2, 
  idaym in varchar2, idayd in varchar2, idayy in varchar2, 
  idoctor_order in varchar2, iparent_permission in varchar2, isignature in varchar2, 
  isignature_daym in varchar2, isignature_dayd in varchar2, isignature_dayy in varchar2, 
  idoctor_initial in varchar2, ititle in varchar2);  
procedure delete_action(cookie in varchar2, iid in varchar2); 
end;  
/
show errors;
-- /

---------------------------------------------------------  
create or replace package body cw_medicat is  
---------------------------------------------------------  
   me varchar2(64);
  this cw_medicat_table%type;
  lstu cw_student_table%type;
  lnur cw_nurse_table%type;
--  id_null exception;
  lday date;
  lsignature_day date;
  cursor nrow is
     select * from cw_medicat_table order by day;
--
---------------------------------------------------------  
procedure rm (iid in number) is
---------------------------------------------------------  
    begin
      delete from cw_medicat_table 
        where id = iid;
--      htp.p('rm:iid='||to_char(iid));
      exception
        when others then
	  cw_error.panic('cw_medicat.rm iid=' || to_char(iid),sqlerrm);
  end;
--
---------------------------------------------------------  
function get(iid in number) return cw_medicat_table%rowtype is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_medicat_table the
      where the.id = this_id;
  begin
    open c (iid);
    fetch c into this;
    if c%notfound then
      raise no_data_found;
    end if;
    close c;
    return this;
    exception
      when no_data_found then
        raise;
      when others then
	cw_error.panic('cw_medicat.get iid=' || to_char(iid),sqlerrm);
  end;
--
---------------------------------------------------------  
  procedure put(iorow in out cw_medicat_table%rowtype) is
---------------------------------------------------------  
    cursor c (this_id number) is
      select * from cw_medicat_table
      where id = this_id
      for update  of day;
    begin
      if (iorow.id is null) then
	select cw_medicat_seq.nextval into iorow.id
	  from dual;
        insert into cw_medicat_table
	  values
	  ( iorow.id, iorow.student_id, iorow.nurse_id,
           iorow.name, iorow.reason, 
           iorow.dosage, iorow.day, iorow.doctor_order, 
           iorow.parent_permission, iorow.signature, iorow.signature_day, 
           iorow.doctor_initial, iorow.title  
          );
      else
        open c (iorow.id);
	fetch c into this;
	if c%found then
	  update  cw_medicat_table set
            id = iorow.id,
            student_id = iorow.student_id,
            nurse_id = iorow.nurse_id,
            name = iorow.name,
            reason = iorow.reason,
            dosage = iorow.dosage,
            day = iorow.day,
            doctor_order = iorow.doctor_order,
            parent_permission = iorow.parent_permission,
            signature = iorow.signature,
            signature_day = iorow.signature_day,
            doctor_initial = iorow.doctor_initial,
            title = iorow.title
	  where id = iorow.id;
	else
	  raise no_data_found;
	end if;
        close c;
      end if;
    exception
      when others then
	cw_error.panic('cw_medicat.put iorow.id=' ||iorow.id, sqlerrm);
    end;
--
---------------------------------------------------------  
function new(iorow in out cw_medicat_table%rowtype) return cw_medicat_table.id%type is
---------------------------------------------------------  
begin
  iorow.id := null;
  put(iorow);
  return iorow.id;
  exception
    when others then
      cw_error.panic('cw_medicat.new iorow.id=' ||iorow.id, sqlerrm);
end;
--
---------------------------------------------------------  
function next(ionrow in out cw_medicat_table%rowtype) return boolean is
---------------------------------------------------------  
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into ionrow;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_medicat.next',sqlerrm);

end;

---------------------------------------------------------  
procedure insert_action(cookie in varchar2,
  iname in varchar2,  ireason in varchar2, idosage in varchar2, 
  idaym in varchar2, idayd in varchar2, idayy in varchar2, 
  idoctor_order in varchar2, iparent_permission in varchar2, isignature in varchar2, 
  isignature_daym in varchar2, isignature_dayd in varchar2, isignature_dayy in varchar2, 
  idoctor_initial in varchar2, ititle in varchar2) is
---------------------------------------------------------  
begin
  me := 'cw_medicat.insert_action';
  cw_bridge.sync(me, cookie);
--  this := cw_bridge.get_immun;
  lstu := cw_bridge.get_student;
  lnur := cw_bridge.get_nurse;
  lday := to_date(idaym||idayd||idayy, 'MONDDYYYY');
  lsignature_day := to_date(isignature_daym||isignature_dayd||isignature_dayy, 'MONDDYYYY');
  this.student_id := lstu.id;
  this.nurse_id := lnur.id;
  this.name := iname;
  this.reason := ireason;
  this.dosage := idosage;
  this.day := lday;
  this.doctor_order := idoctor_order;
  this.parent_permission := iparent_permission;
  this.signature := isignature;
  this.signature_day  := lsignature_day;
  this.doctor_initial := idoctor_initial;
  this.title := ititle;
  this.id := new(this);
  cw_bridge.set_medicat(this);
  cw_medicat_util.action_echo(cookie, this, 'inserted');
  exception
    when others then
      cw_error.panic(me|| ':', sqlerrm);
end;  

---------------------------------------------------------  
procedure update_action(cookie in varchar2,
  iname in varchar2,  ireason in varchar2, idosage in varchar2, 
  idaym in varchar2, idayd in varchar2, idayy in varchar2, 
  idoctor_order in varchar2, iparent_permission in varchar2, isignature in varchar2, 
  isignature_daym in varchar2, isignature_dayd in varchar2, isignature_dayy in varchar2, 
  idoctor_initial in varchar2, ititle in varchar2) is
---------------------------------------------------------  
begin  
  me := 'cw_medicat.update_action';
  cw_bridge.sync(me, cookie);
  this := cw_bridge.get_medicat;
--  lstu := cw_bridge.get_student;
--  lnur := cw_bridge.get_nurse;
  lday := to_date(idaym||idayd||idayy, 'MONDDYYYY');
  lsignature_day := to_date(isignature_daym||isignature_dayd||isignature_dayy, 'MONDDYYYY');
--  this.student_id := cw_bridge.stu.id;
--  this.nurse_id := cw_bridge.nur.id;
  this.name := iname;
  this.reason := ireason;
  this.dosage := idosage;
  this.day := lday;
  this.doctor_order := idoctor_order;
  this.parent_permission := iparent_permission;
  this.signature := isignature;
  this.signature_day  := lsignature_day;
  this.doctor_initial := idoctor_initial;
  this.title := ititle;
  put(this);
  cw_medicat_util.action_echo(cookie, this, 'updated');
--  end if;
  exception
    when others then
      cw_error.panic(me|| ':', sqlerrm); 
end;  

---------------------------------------------------------  
procedure delete_action(cookie in varchar2, iid in varchar2) is
---------------------------------------------------------  
  lid varchar2(8);
begin  
  lid := iid;
  me := 'cw_medicat.delete_action';
  cw_bridge.sync(me, cookie);
--  if (this.id = null) then
--    raise id_null;
--  end if;
--  if (iid = null) then
--    raise id_null;
--  end if;
  cw_medicat_util.action_echo(cookie, this, 'deleted');
  cw_bridge.unset_medicat;  
--  htp.p('delete_action:iid='||iid);
  rm(to_number(lid));
exception
--    when id_null then
--      cw_error.msg(me|| ': iid is null'); 
    when others then
      cw_error.panic(me|| ':', sqlerrm); 
end;  

---------------------------------------------------------  
-- begin
--	this.id := 0;
-- end;
---------------------------------------------------------  

---------------------------------------------------------  
end;  
---------------------------------------------------------  

/
show errors;
-- /

