--------------------------------------------------------------------
create or replace package cw_parent is
--------------------------------------------------------------------
procedure put(r in out cw_parent_table%rowtype);
function get(iid in number) return cw_parent_table%rowtype;
function next(n in out cw_parent_table%rowtype) return boolean;
function new return cw_parent_table%rowtype;
procedure rm(iid in number);
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_parent is
--------------------------------------------------------------------
this cw_parent_table%rowtype;

cursor nrow is
   select * from cw_parent_table;
--------------------------------------------------------------------
procedure put(r in out cw_parent_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_parent_table
   where id = this_id
   for update of person_id;

   begin
	if r.id is null then
	   select cw_parent_seq.nextval into r.id
	   from dual;
	   insert into cw_parent_table
	   (id,person_id,cust_id,student_id)
	   values
	   (r.id,r.person_id,r.cust_id,r.student_id);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_parent_table set
		   person_id	= r.person_id,
		   cust_id	= r.cust_id,
		   student_id	= r.student_id
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_parent.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_parent_table%rowtype is
cursor c (this_id number) is
   select * from cw_parent_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_parent.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_parent_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_parent.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_parent_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_parent_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_parent.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------

end;
/
show errors
