--------------------------------------------------------------------
create or replace package cw_school is
--------------------------------------------------------------------
procedure put(r in out cw_school_table%rowtype);
function get(iid in number) return cw_school_table%rowtype;
function next(n in out cw_school_table%rowtype) return boolean;
function new return cw_school_table%rowtype;
procedure rm(iid in number);
function rowcount return number;
procedure make(cookie in varchar2, handler in varchar2,
	name in varchar2,
	lev in varchar2,
	district in varchar2,
	media_url in varchar2,
	street in varchar2,
	city in varchar2,
	state in varchar2,
	zip in varchar2,
	county in varchar2,
	country in varchar2,
	phone in varchar2,
	fax in varchar2,
	email in varchar2,
	url in varchar2,
	description in varchar2,
	comments in varchar2); 

end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_school is
--------------------------------------------------------------------
this cw_school_table%rowtype;

cursor nrow is
   select * from cw_school_table;
--------------------------------------------------------------------
procedure put(r in out cw_school_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_school_table
   where id = this_id
   for update of email;

   begin
	if r.id is null then
	   select cw_school_seq.nextval into r.id
	   from dual;
	   insert into cw_school_table
	   (id,name,lev,district,media_url,
	    street,city,state,zip,county,country,
	    phone,fax,email,url,description,comments)
	   values
	   (r.id,r.name,r.lev,r.district,r.media_url,
	    r.street,r.city,r.state,r.zip,r.county,r.country,
	    r.phone,r.fax,r.email,r.url,r.description,r.comments);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_school_table set
		   name		= r.name,
		   lev		= r.lev,
		   district	= r.district,
		   media_url	= r.media_url,
		   street	= r.street,
		   city		= r.city,
		   state	= r.state,
		   zip		= r.zip,
		   county	= r.county,
		   country	= r.country,
		   phone	= r.phone,
		   fax		= r.fax,
		   email	= r.email,
		   url		= r.url,
		   description	= r.description,
		   comments	= r.comments
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
	commit;
   exception	   
	when others then
	   cw_error.panic('cw_school.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_school_table%rowtype is
cursor c (this_id number) is
   select * from cw_school_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_school.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_school_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_school.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_school_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_school_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_school.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_school_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_school.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------

procedure make(cookie in varchar2, handler in varchar2,
	name in varchar2,
	lev in varchar2,
	district in varchar2,
	media_url in varchar2,
	street in varchar2,
	city in varchar2,
	state in varchar2,
	zip in varchar2,
	county in varchar2,
	country in varchar2,
	phone in varchar2,
	fax in varchar2,
	email in varchar2,
	url in varchar2,
	description in varchar2,
	comments in varchar2)  is
r cw_school_table%rowtype;
begin
	r.name 		:= name;
	r.lev		:= lev;
	r.district	:= district;
	r.media_url	:= media_url;
	r.street	:= street;
	r.city		:= city;
	r.state		:= state;
	r.zip		:= zip;
	r.county	:= county;
	r.country	:= country;
	r.phone		:= phone;
	r.fax		:= fax;
	r.email		:= email;
	r.url		:= url;
	r.description	:= description;
	r.comments	:= comments;

	if handler = 'cw_school_mgr.create_action' then
		cw_school_mgr.create_action(cookie,r);
	elsif handler = 'cw_school_mgr.modify_action' then
		cw_school_mgr.modify_action(cookie,r);
	else
		null;
	end if;
end;
----------------------------------------------------------------------

end;
/
show errors
