--------------------------------------------------------------------
create or replace package cw_state is
--------------------------------------------------------------------
procedure put(s in out cw_state_table%rowtype);
function get(iid in number) return cw_state_table%rowtype;
function get(sid in varchar2) return cw_state_table%rowtype;
function get return cw_state_table%rowtype;
function next(n in out cw_state_table%rowtype) return boolean;
function new return cw_state_table%rowtype;
procedure rm(iid in number);
function rowcount return number;
procedure setenv;
procedure cleanup;
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_state is
--------------------------------------------------------------------
this cw_state_table%rowtype;
state_not_initialized exception;
invalid_cookie exception;

cursor nrow is
   select * from cw_state_table
   order by timestamp;
--------------------------------------------------------------------
procedure put(s in out cw_state_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_state_table
   where id = this_id
   for update of timestamp;

   begin
	if s.id is null then
	   select cw_state_seq.nextval into s.id
	   from dual;
	   insert into cw_state_table
	   (id,timestamp,cust_id,counter,module,
	    auth_type,gateway_interf,http_user_agent,
	    path_info,path_translated,remote_host,remote_addr,
	    remote_user,remote_ident,remote_protocol,
	    server_name,server_port,person_id,
	    nurse_id,student_id,school_id,npract_id,doctor_id,
	    infopage_id,
	    careinfo_id,immun_id,basescr_id,physscr_id,
	    develscr_id,hhistory_id,visit_id,assess_id,
	    asthma_id,pharyn_id,labrep_id,
	    prognote_id,growth_id,hplan_id,medicat_id,
	    pagemode,reccomp,page_id)
	   values
	   (s.id,s.timestamp,s.cust_id,s.counter,s.module,
	    s.auth_type,s.gateway_interf,s.http_user_agent,
	    s.path_info,s.path_translated,s.remote_host,s.remote_addr,
	    s.remote_user,s.remote_ident,s.remote_protocol,
	    s.server_name,s.server_port,s.person_id,
	    s.nurse_id,s.student_id,s.school_id,s.npract_id,s.doctor_id,
	    s.infopage_id,
	    s.careinfo_id,s.immun_id,s.basescr_id,s.physscr_id,
	    s.develscr_id,s.hhistory_id,s.visit_id,s.assess_id,
	    s.asthma_id,s.pharyn_id,s.labrep_id,
	    s.prognote_id,s.growth_id,s.hplan_id,s.medicat_id,
	    s.pagemode,s.reccomp,s.page_id);
	else
	   open c (s.id);
	   fetch c into this;
	   if c%found then
		update cw_state_table set
		   id		= s.id,
		   timestamp	= s.timestamp,
		   cust_id		= s.cust_id,
		   counter		= s.counter,
		   module		= s.module,
		   auth_type	= s.auth_type,
		   gateway_interf	= s.gateway_interf,
		   http_user_agent	= s.http_user_agent,
		   path_info	= s.path_info,
		   path_translated	= s.path_translated,
		   remote_host	= s.remote_host,
		   remote_addr	= s.remote_addr,
		   remote_user	= s.remote_user,
		   remote_ident	= s.remote_ident,
		   remote_protocol	= s.remote_protocol,
		   server_software	= s.server_software,
		   server_name	= s.server_name,
		   server_port	= s.server_port,
		   person_id	= s.person_id,
		   nurse_id	= s.nurse_id,
		   student_id	= s.student_id,
		   school_id	= s.school_id,
		   npract_id	= s.npract_id,
		   doctor_id	= s.doctor_id,
		   infopage_id	= s.infopage_id,
		   careinfo_id	= s.careinfo_id,
		   immun_id	= s.immun_id,
		   basescr_id	= s.basescr_id,
		   physscr_id	= s.physscr_id,
		   develscr_id	= s.develscr_id,
		   hhistory_id	= s.hhistory_id,
		   visit_id	= s.visit_id,
		   assess_id	= s.assess_id,
		   asthma_id	= s.asthma_id,
		   pharyn_id	= s.pharyn_id,
		   prognote_id	= s.prognote_id,
		   growth_id	= s.growth_id,
		   hplan_id	= s.hplan_id,
		   medicat_id	= s.medicat_id,
		   pagemode	= s.pagemode,
		   reccomp		= s.reccomp,
		   page_id		= s.page_id
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
   exception	   
	when others then
	   cw_error.panic('cw_state.put id='||to_char(s.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_state_table%rowtype is
cursor c (this_id number) is
   select * from cw_state_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_state.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function get(sid in varchar2) return cw_state_table%rowtype is
begin
   return get(to_number(sid));
end;
---------------------------------------------------------------------
function get return cw_state_table%rowtype is
begin
   if this.id is null then
	raise state_not_initialized;
   end if;
   return this;
end;
---------------------------------------------------------------------
function next(n in out cw_state_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_state.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_state_table%rowtype is
begin
   this.id := null;
   setenv;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_state_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_state.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_state_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_state.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------
procedure setenv is
begin
/*
   this.auth_type         := owa.auth_type;
   this.gateway_interf    := owa.gateway_interface;
   this.http_user_agent   := owa.http_user_agent;
   this.remote_host       := owa.remote_host;
   this.remote_addr       := owa.remote_addr;
   this.remote_user       := owa.remote_user;
   this.remote_ident      := owa.remote_ident;
   this.server_software   := owa.server_software;
   this.server_name       := owa.server_name;
   this.server_port       := owa.server_port;
*/
   this.auth_type         := owa_util.get_cgi_env('AUTH_TYPE');
   this.gateway_interf    := owa_util.get_cgi_env('GATEWAY_INTERFACE');
   this.http_user_agent   := owa_util.get_cgi_env('HTTP_USER_AGENT');
   this.remote_host       := owa_util.get_cgi_env('REMOTE_HOST');
   this.remote_addr       := owa_util.get_cgi_env('REMOTE_ADDR');
   this.remote_user       := owa_util.get_cgi_env('REMOTE_USER');
   this.remote_ident      := owa_util.get_cgi_env('REMOTE_IDENT');
   this.server_software   := owa_util.get_cgi_env('SERVER_SOFTWARE');
   this.server_name       := owa_util.get_cgi_env('SERVER_NAME');
   this.server_port       := owa_util.get_cgi_env('SERVER_PORT');

end;
---------------------------------------------------------------------
procedure cleanup is
begin
   delete from cw_state_table
   where timestamp < sysdate - (1/24);
exception
   when no_data_found then
	null;
   when others then
	cw_error.panic('cw_state.cleanup',sqlerrm);
end;
---------------------------------------------------------------------
end;
/
show errors
