-----------------------------------------------------------------------------
create or replace package cw_tx is
-----------------------------------------------------------------------------
procedure open;
procedure put(t in out cw_tx_table%rowtype);
function get(iid in number) return cw_tx_table%rowtype;
function next(t in out cw_tx_table%rowtype) return boolean;
procedure rm(iid in number);
function rowcount return number;

type tx_name_type is table of varchar2(32) index by binary_integer;
t_name  tx_name_type;
a_name  tx_name_type;
isclosed boolean := true;

t_login		constant number(2) := 1;	
t_register	constant number(2) := 2;
t_page		constant number(2) := 3;
t_collab	constant number(2) := 4;
t_logout	constant number(2) := 5;
t_panic		constant number(2) := 6;

t_person	constant number(2) := 11;
t_guest		constant number(2) := 12;
t_nurse		constant number(2) := 13;
t_student	constant number(2) := 14;
t_npract	constant number(2) := 15;
t_doctor	constant number(2) := 16;
t_parent	constant number(2) := 17;
t_root		constant number(2) := 18;

t_immunization	constant number(2) := 21;
t_basescrt	constant number(2) := 22;
t_physscrt	constant number(2) := 23;
t_devscrt	constant number(2) := 24;
t_visitlog	constant number(2) := 25;
t_assessform	constant number(2) := 26;
t_prognote	constant number(2) := 27;
t_medication	constant number(2) := 28;
t_parentform	constant number(2) := 29;

a_accept	constant number(2) := 1;
a_reject	constant number(2) := 2;
a_create	constant number(2) := 3;
a_modify	constant number(2) := 4;
a_delete	constant number(2) := 5;
a_view		constant number(2) := 6;
a_search	constant number(2) := 7;
a_print		constant number(2) := 8;
a_send		constant number(2) := 9;

end;
/
show errors
-----------------------------------------------------------------------------
create or replace package body cw_tx is
-----------------------------------------------------------------------------
this cw_tx_table%rowtype;

cursor nrow is
   select * from cw_tx_table
   order by timestamp;
-----------------------------------------------------------------------------
procedure open is
begin
   if isclosed then
	isclosed := false;

	t_name(1)  := 'login';
	t_name(2)  := 'register';
	t_name(3)  := 'page';
	t_name(4)  := 'collab';
	t_name(5)  := 'logout';
	t_name(6)  := 'panic';

	t_name(11) := 'person';
	t_name(12) := 'guest';
	t_name(13) := 'nurse';
	t_name(14) := 'student';
	t_name(15) := 'npract';
	t_name(16) := 'doctor';
	t_name(17) := 'parent';
	t_name(18) := 'root';

	t_name(21) := 'immunization';
	t_name(22) := 'screening test';
	t_name(23) := 'physical';
	t_name(24) := 'developmental';
	t_name(25) := 'visit log';
	t_name(26) := 'assessment form';
	t_name(27) := 'progress note';
	t_name(28) := 'medication';
	t_name(29) := 'parent form';

	a_name(1)  := 'accept';
	a_name(2)  := 'reject';
	a_name(3)  := 'create';
	a_name(4)  := 'modify';
	a_name(5)  := 'delete';
	a_name(6)  := 'view';
	a_name(7)  := 'search';
	a_name(8)  := 'print';
	a_name(9)  := 'send';
   end if;
end;
-----------------------------------------------------------------------------
procedure put(t in out cw_tx_table%rowtype) is
cursor c (this_id number) is
   select * from cw_tx_table 
   where id = this_id
   for update of timestamp;
begin
   t.timestamp := sysdate;
   if(t.id is null) then
	select cw_tx_seq.nextval into t.id
	from dual;
	insert into cw_tx_table
	(id,timestamp,cust_id,url,target,action,
	 auth_type,gateway_interf,http_user_agent,
	 path_info,path_translated,remote_host,remote_addr,
	 remote_user,remote_ident,remote_protocol,
	 server_software,server_name,server_port,
	 nr1,nr2,nr3,nr4,sr1,sr2,sr3,sr4)
	values
	(t.id,t.timestamp,t.cust_id,t.url,t.target,t.action,
	 t.auth_type,t.gateway_interf,t.http_user_agent,
	 t.path_info,t.path_translated,t.remote_host,t.remote_addr,
	 t.remote_user,t.remote_ident,t.remote_protocol,
	 t.server_software,t.server_name,t.server_port,
	 t.nr1,t.nr2,t.nr3,t.nr4,t.sr1,t.sr2,t.sr3,t.sr4);	
   else
	open c (t.id);
	fetch c into this;
   	if(c%found) then
	   update cw_tx_table set
		timestamp	= t.timestamp,
		cust_id		= t.cust_id,
		url		= t.url,
		target		= t.target,
		action		= t.action,
		auth_type	= t.auth_type,
		gateway_interf	= t.gateway_interf,
		http_user_agent	= t.http_user_agent,
		path_info	= t.path_info,
		path_translated	= t.path_translated,
		remote_host	= t.remote_host,
		remote_addr	= t.remote_addr,
		remote_user	= t.remote_user,
		remote_ident	= t.remote_ident,
		remote_protocol	= t.remote_protocol,
		server_software	= t.server_software,
		server_name	= t.server_name,
		server_port	= t.server_port
	   where id = t.id;
	else
	   raise no_data_found;
	end if;
	close c;
   end if;
exception
   when others then
	cw_error.panic('cw_tx.put id='||to_char(t.id),sqlerrm);
end;
------------------------------------------------------------------------------
function get(iid in number) return cw_tx_table%rowtype is
cursor c (this_id number) is
   select * from cw_tx_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
	raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
	raise;
   when others then
	cw_error.panic('cw_tx.get id='||to_char(iid),sqlerrm);
end;
------------------------------------------------------------------------------
function get return cw_tx_table%rowtype is
begin
   return this;
end;
------------------------------------------------------------------------------
function next(t in out cw_tx_table%rowtype) return boolean is
begin
   if not nrow%isopen then
	open nrow;
   end if;
   fetch nrow into t;
   if nrow%notfound then
	close nrow;	
	return false;
   else
	return true;
   end if;
exception
   when others then
	cw_error.panic('cw_tx.next',sqlerrm);
end;
------------------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_tx_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_tx.rm id='||to_char(iid),sqlerrm);
end;
------------------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_tx_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
	return 0;
   else
	return cnt;
   end if;
exception
   when others then
	cw_error.panic('cw_tx.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------
end;
/
show errors
