--------------------------------------------------------------------
create or replace package cw_visit is
--------------------------------------------------------------------
procedure put(r in out cw_visit_table%rowtype);
function get(iid in number) return cw_visit_table%rowtype;
function next(n in out cw_visit_table%rowtype) return boolean;
function new return cw_visit_table%rowtype;
procedure rm(iid in number);
function rowcount return number;
procedure make(cookie in varchar2, handler in varchar2,
	daym in varchar2,
	dayd in varchar2,
	dayy in varchar2,
	reason in varchar2,
	diagnosis in varchar2,
	resolution in varchar2,
	comments in varchar2);
end;
/
show errors
--------------------------------------------------------------------
create or replace package body cw_visit is
--------------------------------------------------------------------
this cw_visit_table%rowtype;

cursor nrow is
   select * from cw_visit_table;
--------------------------------------------------------------------
procedure put(r in out cw_visit_table%rowtype) is
   cursor c (this_id in number) is
   select * from cw_visit_table
   where id = this_id
   for update of student_id;

   begin
	if r.id is null then
	   select cw_visit_seq.nextval into r.id
	   from dual;
	   insert into cw_visit_table
	   (id,student_id,nurse_id,day,reason,diagnosis,
	    resolution,code,comments,assess_id,prognote_id,
	    consult_id)
	   values
	   (r.id,r.student_id,r.nurse_id,r.day,r.reason,r.diagnosis,
	    r.resolution,r.code,r.comments,r.assess_id,r.prognote_id,
	    r.consult_id);
	else
	   open c (r.id);
	   fetch c into this;
	   if c%found then
		update cw_visit_table set
		   student_id		= r.student_id,
		   nurse_id		= r.nurse_id,
		   day			= r.day,
		   reason		= r.reason,
		   diagnosis		= r.diagnosis,
		   resolution		= r.resolution,
		   code			= r.code,
		   comments		= r.comments,
		   assess_id		= r.assess_id,
		   prognote_id		= r.prognote_id,
		   consult_id		= r.consult_id
		where current of c;
	   else
		raise no_data_found;
	   end if;
	   close c;
	end if;
	commit;
   exception	   
	when others then
	   cw_error.panic('cw_visit.put id='||to_char(r.id),sqlerrm);
end;
---------------------------------------------------------------------
function get(iid in number) return cw_visit_table%rowtype is
cursor c (this_id number) is
   select * from cw_visit_table
   where id = this_id;
begin
   open c(iid);
   fetch c into this;
   if c%notfound then
        raise no_data_found;
   end if;
   close c;
   return this;
exception
   when no_data_found then
        raise;
   when others then
        cw_error.panic('cw_visit.get id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function next(n in out cw_visit_table%rowtype) return boolean is
begin
   if not nrow%isopen then
        open nrow;
   end if;
   fetch nrow into n;
   if nrow%notfound then
        close nrow;     
        return false;
   else
        return true;
   end if;
exception
   when others then
        cw_error.panic('cw_visit.next',sqlerrm);

end;
---------------------------------------------------------------------
function new return cw_visit_table%rowtype is
begin
   this.id := null;
   put(this);
   return this;
end;
---------------------------------------------------------------------
procedure rm(iid in number) is
        begin
   delete from cw_visit_table
   where id = iid;
exception
   when others then
        cw_error.panic('cw_visit.rm id='||to_char(iid),sqlerrm);
end;
---------------------------------------------------------------------
function rowcount return number is
cnt number(9);
cursor c is
   select count(id) from cw_visit_table;
begin
   open c;
   fetch c into cnt;
   if c%notfound then
        return 0;
   else
        return cnt;
   end if;
exception
   when others then
        cw_error.panic('cw_visit.rowcount',sqlerrm);
end;
------------------------------------------------------------------------------
procedure make(cookie in varchar2, handler in varchar2,
	daym in varchar2,
	dayd in varchar2,
	dayy in varchar2,
	reason in varchar2,
	diagnosis in varchar2,
	resolution in varchar2,
	comments in varchar2) is
r cw_visit_table%rowtype;
begin
	r.day			:= to_date(daym||dayd||dayy,'MONDDYYYY');
	r.reason		:= reason;
	r.diagnosis		:= diagnosis;
	r.resolution		:= resolution;
	r.comments		:= comments;
	
	if handler = 'cw_visit_mgr.create_action' then
		cw_visit_mgr.create_action(cookie,r);
	elsif handler = 'cw_visit_mgr.modify_action' then
		cw_visit_mgr.modify_action(cookie,r);
	else
		null;
	end if;
end;
----------------------------------------------------------------------

end;
/
show errors
