-----------------------------------------------------------------------------
create or replace package cw_visit_mgr is
-----------------------------------------------------------------------------
procedure show_cmd(cookie in varchar2, iid in number);
procedure bar_page(cookie in varchar2);
procedure bar_action(cookie in varchar2, cmd in varchar2);
procedure actbar_action(cookie in varchar2, 
   act in varchar2, sign in varchar2);

procedure out_cmd(cookie in varchar2);
procedure home_cmd(cookie in varchar2);
procedure all_cmd(cookie in varchar2);
procedure select_cmd(cookie in varchar2);
procedure filter_cmd(cookie in varchar2);
procedure create_cmd(cookie in varchar2);
procedure create_action(cookie in varchar2, r in cw_visit_table%rowtype);
procedure modify_cmd(cookie in varchar2);
procedure modify_action(cookie in varchar2, r in cw_visit_table%rowtype);
procedure delete_cmd(cookie in varchar2);
procedure save_cmd(cookie in varchar2);
procedure load_cmd(cookie in varchar2);
procedure help_cmd(cookie in varchar2);

procedure err_notimpl(cookie in varchar2);
procedure err_nocurrent(cookie in varchar2,key in varchar2);

invalid_command exception;
no_current_visit exception;
no_current_student exception;
no_current_nurse exception;
no_current_school exception;
breakit exception;

end;
/
show errors
-----------------------------------------------------------------------------
create or replace package body cw_visit_mgr is
-----------------------------------------------------------------------------
me varchar2(64);
url varchar2(64) := cw_util.getURL;
curr_cmd varchar2(32);
-----------------------------------------------------------------------------
procedure show_cmd(cookie in varchar2, iid in number) is
vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;

begin
   me := 'cw_visit_mgr.show_cmd';
   cw_bridge.sync(me,cookie);

   
   vis := cw_visit.get(iid);
   stu := cw_student.get(vis.student_id);
   per := cw_person.get(stu.person_id);
   cw_bridge.set_visit(vis);

   cw_util.pageOpen('CareWeb VisitLog Manager: '||
	per.first_name||' '||per.middle_name||' '||per.last_name);
   htp.p('<CENTER>');
   cw_visit_util.show_form(vis);

   htp.hr;
   htp.formOpen('cw_visit_mgr.actbar_action');
   htp.formHidden('cookie',cookie);
   cw_visit_util.actbar_form(vis);
   htp.formClose;

   htp.p('</CENTER>');
   cw_util.pageClose;

exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure actbar_action(cookie in varchar2, 
   act in varchar2, sign in varchar2) is
vis cw_visit_table%rowtype;
begin
   me := 'cw_visit_mgr.actbar_action';
   cw_bridge.sync(me,cookie); 

   vis := cw_bridge.get_visit;
   if act = ' Fill Assessment Form ' then
	if vis.reason = 'Asthma' then
		cw_asthma_mgr.home_cmd(cookie);
	elsif vis.reason = 'Pharyngitis' then
		cw_assess_mgr.home_cmd(cookie);
	else
		htp.p('Not Implemented Reason = '||vis.reason);
	end if;
   elsif act = ' Contact NP ' then
	cw_npract_mgr.show_cmd(cookie,1);
   elsif act = ' Contact MD ' then
	cw_doctor_mgr.show_cmd(cookie,1);
   elsif act = ' Consult WebMed Pages ' then
	cw_visit_util.infopage_directory(cookie,vis);
   else
	htp.p('Not Implemented Action = '||act);
   end if;
	
end;
------------------------------------------------------------------------------
procedure bar_page(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.bar_page';
  -- url := 'http://kayak.npac.syr.edu:9602/cgi-bin/wow/';
   cw_util.jsOpen;
   cw_util.docOpen('cmd');
   cw_util.docWrite('cmd',
	'<html><body bgcolor="darkgreen"><font size=5 color="ivory"><center>');
   cw_util.docWrite('cmd',
	'<form action= "'||url||'cw_visit_mgr.bar_action" target="view">');
   cw_util.docWrite('cmd',
	'<input type="hidden" name="cookie" value="'||cookie||'">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Out">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Home">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="All">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Select">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Filter">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Create">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Modify">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Delete">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Save">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Load">');
   cw_util.docWrite('cmd',
	'<input type="submit" name="cmd" value="Help">');
    cw_util.docWrite('cmd',
	'</form></center></font></body></html>');
   cw_util.docClose('cmd');
   cw_util.jsClose;
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure bar_action(cookie in varchar2, cmd in varchar2) is
begin
   me := 'cw_visit_mgr.bar_action';
   cw_bridge.sync(me,cookie);

   curr_cmd := cmd;

   if cmd = 'Out' then
	out_cmd(cookie);
   elsif cmd = 'Home' then
	home_cmd(cookie);
   elsif cmd = 'All' then
	all_cmd(cookie);
   elsif cmd = 'Select' then
	select_cmd(cookie);
   elsif cmd = 'Filter' then
	filter_cmd(cookie);
   elsif cmd = 'Create' then
	create_cmd(cookie);
   elsif cmd = 'Modify' then
	modify_cmd(cookie);
   elsif cmd = 'Delete' then
	delete_cmd(cookie);
   elsif cmd = 'Save' then
	save_cmd(cookie);
   elsif cmd = 'Load' then
	load_cmd(cookie);
   elsif cmd = 'Help' then
	help_cmd(cookie);
   else 
	raise invalid_command;
   end if;
exception
   when invalid_command then
	cw_error.die(me,'Invalid command = '||cmd||'.');
   when others then
	cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure out_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.out_cmd';
   cw_bridge.sync(me,cookie);

   cw_bridge.unset_visit;
   cw_bridge.unset_school;
   cw_bridge.unset_student;
   cw_bridge.unset_nurse;
   cw_table_mgr.home_cmd(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure home_cmd(cookie in varchar2) is
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
icon_url varchar2(128);
icon_action varchar2(128);
per_photo varchar2(128);
begin
   me := 'cw_visit_mgr.home_cmd';
   cw_bridge.sync(me,cookie);

   stu := cw_bridge.get_student;

   if stu.id is null then
	icon_url := 
	'http://www.npac.syr.edu/users/sangeeta/media_url/database.gif';
   	icon_action := 'cw_table_mgr.home_cmd';
	cw_table_mgr.all_list(cookie);
  else
	per := cw_person.get(stu.person_id);
	if per.media_url is null then
	icon_url := 
	'/careweb/images/shrideep.jpg'; 
	else
	per_photo := per.media_url||'/photo.gif';
	icon_url := 
	'http://www.npac.syr.edu/users/sangeeta/media_url/'||per_photo;
	end if;
	icon_action := 'cw_student_mgr.show_cmd';
	cw_student_mgr.dir_list(cookie);	

   end if;	

   cw_util.cntl_putimg(cookie,icon_url,icon_action);

   bar_page(cookie);
   all_cmd(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure all_cmd(cookie in varchar2) is
vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
sch cw_school_table%rowtype;

cnt number(6);
ncol number(2) := 1;
i number(2);
id number;
stu_name varchar2(128);
sch_name varchar2(128);
idate varchar2(16);

begin
   me := 'cw_visit_mgr.all_cmd';
   cw_bridge.sync(me,cookie);

--   cw_util.pageOpen('CareWeb VisitLog Manager: All Records');
   cw_util.iconPageOpen('CareWeb Progress Note Manager: ',
	'All Records',
	'http://www.npac.syr.edu/users/sangeeta/media_url/progress_note1.gif');
   htp.p('<center>');

   htp.tableOpen(cattributes=>'border=5');
   htp.tableRowOpen;
   for j in 1..ncol loop
   htp.tableHeader('Date');
   htp.tableHeader('Name');
   htp.tableHeader('School');
   htp.tableHeader('Reason');
   htp.tableHeader('Diagnosis');
   if j < ncol then
	htp.tableHeader('   ');
   end if;
   end loop;
   htp.tableRowClose;

   htp.tableRowOpen;
   i := 1; 
   while(cw_visit.next(vis)) loop
	if i = 1 then
		htp.tableRowOpen;
	end if;
	stu := cw_student.get(vis.student_id);
	per := cw_person.get(stu.person_id);
	sch := cw_school.get(stu.school_id);
	sch_name := sch.name||' '||sch.lev;
	stu_name := per.first_name||' '||per.middle_name||' '||per.last_name;
	idate := to_char(vis.day,'dd-Mon-yy');
	htp.tableData(htf.anchor('cw_visit_mgr.show_cmd?cookie='
		||cookie||chr(ascii('&'))||'iid='||vis.id,idate));
	htp.tableData(stu_name);
	htp.tableData(sch_name);
	htp.tableData(vis.reason);
	htp.tableData(vis.diagnosis);
	if i < ncol then
		htp.tableData('   ');
		i := i + 1;
	else
		htp.tableRowOpen;
		i := 1;
	end if;
   end loop;
   htp.tableClose;
	
   htp.p('</center>');
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure select_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.select_cmd';
   cw_bridge.sync(me,cookie);

   err_notimpl(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure filter_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.filter_cmd';
   cw_bridge.sync(me,cookie);

   err_notimpl(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure create_cmd(cookie in varchar2) is
stu cw_student_table%rowtype;
nur cw_nurse_table%rowtype;
sch cw_school_table%rowtype;
begin
   me := 'cw_visit_mgr.create_cmd';
   cw_bridge.sync(me,cookie);

   sch := cw_bridge.get_school;
   if sch.id is null then
	raise no_current_school;
   end if;
   nur := cw_bridge.get_nurse;
   if nur.id is null then
	raise no_current_nurse;
   end if;
   stu := cw_bridge.get_student;
   if stu.id is null then
	raise no_current_student;
   end if;


   htp.formOpen('cw_visit.make');
   cw_util.editPageOpen(' CareWeb VisitLog Manager: Create ');
   htp.formHidden('cookie',cookie);
   htp.formHidden('handler','cw_visit_mgr.create_action');
   htp.p('<CENTER>');
   cw_visit_util.create_form;
   htp.p('</CENTER>');
   htp.formClose;
   cw_util.pageClose;
exception
   when no_current_student then
	err_nocurrent(cookie,'student');
   when no_current_school then
	err_nocurrent(cookie,'school');	
   when no_current_nurse then
	err_nocurrent(cookie,'nurse');	
   when others then
	cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure create_action(cookie in varchar2, r in cw_visit_table%rowtype) is
vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
sch cw_school_table%rowtype;
nur cw_nurse_table%rowtype;
begin
   me := 'cw_visit_mgr.create_action';
   cw_bridge.sync(me,cookie);

   vis := r;
   vis.id := null;
   stu := cw_bridge.get_student;
   nur := cw_bridge.get_nurse;
   vis.student_id := stu.id;
   vis.nurse_id := nur.id;
   cw_visit.put(vis);
   cw_bridge.set_visit(vis);
   per := cw_person.get(stu.person_id);
   sch := cw_school.get(stu.school_id);

   cw_util.pageOpen('CareWeb VisitLog Manager: '||
	per.first_name||' '||per.middle_name||' '||per.last_name);
   htp.p('<CENTER>');
   cw_visit_util.show_form(vis);
   htp.hr;
   htp.formOpen('cw_visit_mgr.actbar_action');
   htp.formHidden('cookie',cookie);
   cw_visit_util.actbar_form(vis);
   htp.formClose;
   htp.p('</CENTER>');
   cw_util.pageClose;
exception
   when breakit then
	cw_error.die(me,'test exception');
   when others then
	cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure modify_cmd(cookie in varchar2) is
vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
sch cw_school_table%rowtype;
nur cw_nurse_table%rowtype;
begin
   me := 'cw_visit_mgr.modify_cmd';
   cw_bridge.sync(me,cookie);

   sch := cw_bridge.get_school;
   if sch.id is null then
	raise no_current_school;
   end if;
   nur := cw_bridge.get_nurse;
   if nur.id is null then
	raise no_current_nurse;
   end if;
   stu := cw_bridge.get_student;
   if stu.id is null then
	raise no_current_student;
   end if;
   vis := cw_bridge.get_visit;
   if vis.id is null then 
	raise no_current_visit;
   end if;

   htp.formOpen('cw_visit.make');
   cw_util.editPageOpen(' CareWeb VisitLog Manager: Modify ');
   htp.formHidden('cookie',cookie);
   htp.formHidden('handler','cw_visit_mgr.modify_action');
   htp.p('<CENTER>');
   cw_visit_util.modify_form(vis);
   htp.p('</CENTER>');
   htp.formClose;
   cw_util.pageClose;
exception
   when no_current_visit then
	err_nocurrent(cookie,'care information page');
   when no_current_student then
	err_nocurrent(cookie,'student');
   when no_current_nurse then
	err_nocurrent(cookie,'nurse');
   when no_current_school then
	err_nocurrent(cookie,'school');
   when others then
	cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure modify_action(cookie in varchar2, r in cw_visit_table%rowtype) is
new_vis cw_visit_table%rowtype;
old_vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
sch cw_school_table%rowtype;
nur cw_nurse_table%rowtype;

begin
   me := 'cw_visit_mgr.modify_action';
   cw_bridge.sync(me,cookie);
   
   new_vis := r;
   old_vis := cw_bridge.get_visit;
   stu := cw_student.get(old_vis.student_id);
   new_vis.id := old_vis.id;
   new_vis.student_id := stu.id;
   cw_visit.put(new_vis);
   cw_bridge.set_visit(new_vis);
   per := cw_person.get(stu.person_id);
  
   cw_util.pageOpen('CareWeb VisitLog Manager: '||
	per.first_name||' '||per.middle_name||' '||per.last_name);
   htp.p('<CENTER>');
   cw_visit_util.show_form(new_vis);
   htp.hr;
   htp.formOpen('cw_visit_mgr.actbar_action');
   htp.formHidden('cookie',cookie);
   cw_visit_util.actbar_form(new_vis);
   htp.formClose;
   htp.p('</CENTER>');
   cw_util.pageClose;
exception
   when others then
	cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure delete_cmd(cookie in varchar2) is
vis cw_visit_table%rowtype;
stu cw_student_table%rowtype;
per cw_person_table%rowtype;
sch cw_school_table%rowtype;
nur cw_nurse_table%rowtype;
begin
   me := 'cw_visit_mgr.delete_cmd';
   cw_bridge.sync(me,cookie);

   sch := cw_bridge.get_school;
   if sch.id is null then
	raise no_current_school;
   end if;
   nur := cw_bridge.get_nurse;
   if nur.id is null then
	raise no_current_nurse;
   end if;
   stu := cw_bridge.get_student;
   if stu.id is null then
	raise no_current_student;
   end if;
   vis := cw_bridge.get_visit;
   if vis.id is null then 
	raise no_current_visit;
   end if;

   per := cw_bridge.get_person;

   cw_util.pageOpen('CareWeb VisitLog Manager: '||
        per.first_name||' '||per.middle_name||' '||per.last_name);
   htp.p('<CENTER>');
   cw_visit_util.show_form(vis);
   htp.para;
   htp.p('<font size=7 color="firebrick">DELETED</a>');
   htp.p('</CENTER>');

   cw_visit.rm(vis.id);
   cw_bridge.unset_visit;
   
exception
   when no_current_visit then
	err_nocurrent(cookie,'visit log');
   when no_current_student then
	err_nocurrent(cookie,'student');
   when no_current_nurse then
	err_nocurrent(cookie,'nurse');
   when no_current_school then
	err_nocurrent(cookie,'school');
   when others then
	cw_error.die(me,'No current visit');
end;
-----------------------------------------------------------------------------
procedure save_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.save_cmd';
   cw_bridge.sync(me,cookie);

   err_notimpl(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure load_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.load_cmd';
   cw_bridge.sync(me,cookie);

   err_notimpl(cookie);
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure help_cmd(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.help_cmd';
   cw_bridge.sync(me,cookie);

   cw_util.pageOpen('CareWeb VisitLog Manager: Help','crimson','ivory',7);

   htp.tableOpen(cattributes=>'border=5');

   htp.tableRowOpen;
	htp.tableHeader('Command','center');
	htp.tableHeader('Description','center');
	htp.tableheader('Access','center');
	htp.tableHeader('Status','center');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Out');
	htp.tableData('Exit the current space and move one step up');
	htp.tableData('DBA');
	htp.tableData('Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Home');
	htp.tableData('Home Page for the CareWeb VisitLog Manager');
	htp.tableData('DBA');
	htp.tableData('Now the same as [All]. Soon to include description '||
		'of the overall organization of the CareWeb database');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('All');
	htp.tableData('List all tables in CareWeb database '||
		'with hyperlinks to individual table spaces');
	htp.tableData('DBA');
	htp.tableData('Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Select');
	htp.tableData('List all tables with the multiple choice '||
		'selection support');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Filter');
	htp.tableData('Restrict the list of analyzed records in terms '||
		'of a user-provided filter or query');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Create');
	htp.tableData('Create new record.');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Modify');
	htp.tableData('Modify current record.');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Delete');
	htp.tableData('Delete current selection (record or group).');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Save');
	htp.tableData('Save/dump the current selection');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Load');
	htp.tableData('Fetch the previously daved/dumped selection');
	htp.tableData('DBA');
	htp.tabledata('Not Implemented');
   htp.tableRowClose;

   htp.tableRowOpen;
	htp.tableData('Help');
	htp.tableData('This page - includes short description of all commands');
	htp.tableData('DBA');
	htp.tabledata('Implemented');
   htp.tableRowClose;
   htp.tableClose;

   cw_util.pageClose;
exception

   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure err_notimpl(cookie in varchar2) is
begin
   me := 'cw_visit_mgr.err_notimpl';
   cw_bridge.sync(me,cookie);

   cw_util.pageOpen('CareWeb VisitLog Manager: ERROR','ivory','crimson',7);
   htp.p('<font size=5 color="ivory">');
   htp.para;
   htp.p('Command ['||curr_cmd||'] is not yet implemented for this space. '||
	'Click [Help] to get '||
	' the functionality, access rights and the implementation status '||
	' Not of the individual VisitLog Manager commands.'); 
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
procedure err_nocurrent(cookie in varchar2, key in varchar2) is
begin
   me := 'cw_visit_mgr.err_nocurrent';
   cw_bridge.sync(me,cookie);

   cw_util.pageOpen('CareWeb VisitLog Manager: ERROR','ivory','crimson',7);
   htp.para;
   htp.p('<center><font size=8 color="yellow">');
   htp.p('Current '||key||' is not defined.');
   htp.p('</font></center>');
   htp.para;
   htp.p('<font size=5 color="ivory">');
   htp.p('You have no permission to execute command ['||curr_cmd||
	'] in this space. '||
	'Click [Help] to get '||
	' the functionality, access rights and the implementation status '||
	' of the individual VisitLog Manager commands.'); 
   htp.p('</font>');    
exception
   when others then
   cw_error.die(me,sqlerrm);
end;
-----------------------------------------------------------------------------
end;
/
show errors
